@@ -56,8 +56,9 @@ static char ripe_server[] = "whois.ripe.net";
 static char ripe_ris_server[] = "riswhois.ripe.net";
 
 #ifdef STANDALONE
-const char *version = "3.71";                    /* set version string for library and client */
-const char *appname = "WhoB";            	/* set application name */
+const char *version = "3.72";                    /* set version string for library and client */
+const char *appname = "WhoB";            	    /* set application name */
+static int go_interactive = 0;                  /* We'll wait on STDIN unless args suggest otherwise */
 static int use_cymru = 0;                       /* Don't use Cymru by default */
 static int use_riswhois = 0;                    /* Don't use RIPE NCC RIS by default */
 static int display_orgname = 1;                 /* Display orgname by default */
@@ -2315,28 +2316,33 @@ int main(int ac, char **av)
     
     wsess = w_init();
     setbuf(stdout, NULL);
-    
+        
     while ((ch = getopt (ac, av, "aCcfgNnOopPRrstuVvh:w:")) != EOF)
         switch (ch) {
             case 'a':
                 use_gigo = 0;
                 show_routes_byasn = 1;
+                go_interactive = 1;
                 break;
             case 'N':
                 use_gigo = 0;
                 show_networks_byasn = 1;
+                go_interactive = 1;
                 break;
             case 'O':
                 use_gigo = 0;
                 show_contacts_byasn = 1;
+                go_interactive = 1;
                 break;
             case 's':
                 use_gigo = 0;
                 show_server_status = 1;
+                go_interactive = 1;
                 break;
             case 'P':
                 use_gigo = 0;
                 show_routes_byprefix = 1;
+                go_interactive = 1;
                 break;
             case 'v':
                 usage(av[0]);
@@ -2400,6 +2406,7 @@ int main(int ac, char **av)
                 break;
             case 'n':
                 display_netname = 1;
+                go_interactive = 1;
                 break;
             case 'r':
                 use_riswhois = 1;
@@ -2407,12 +2414,15 @@ int main(int ac, char **av)
                 break;
             case 'R':
                 display_radb_as = 1;
+                go_interactive = 1;
                 break;
             case 'o':
                 display_orgname = 0;
+                go_interactive = 1;
                 break;
             case 'p':
                 display_aspath = 1;
+                go_interactive = 1;
                 break;
             case 'f':
                 use_gigo = 0;
@@ -2423,11 +2433,13 @@ int main(int ac, char **av)
                 break;
             case 'g':
                 use_gigo = 0;
+                go_interactive = 1;
                 break;
             default:
                 usage (av[0]);
         }
-                    
+                            
+    if (go_interactive > 0) {
     /*  Quickly check stdin for input to avoid David having to type   */
     /*  '-f -' to pipe into to whob, even if it has args :-)          */
         fd_set rfds;
@@ -2445,7 +2457,7 @@ int main(int ac, char **av)
      
         if (selretval) {
             /* There's input in them there hills, treat it as the input file */
-            use_gigo = 0;
+            use_gigo = 0; 
             read_from_file = 1;
             use_stdin = 1;
         } 
@@ -2453,26 +2465,34 @@ int main(int ac, char **av)
           else
             if (wsess->w_noisy) fprintf(stderr,"No input found on stdin.\n");
         */
-        
-    if (((ac - optind) < 1) && (show_server_status != 1) && (!read_from_file))
+    } else if (read_from_file < 1) {
+        /* No indication we should be interactive based on arguments, so wait for STDIN */
+        use_gigo = 0;
+        read_from_file = 1;
+        use_stdin = 1;
+    }
+            
+    if (((ac - optind) < 1) && (show_server_status != 1) && (go_interactive > 0))
         usage (av[0]);
         
     /* Show the verbose startup information if verbosity is enabled/requested */
     show_startup_msgs(wsess);
-        
+                    
     if (show_server_status == 1) {
         w_display_pwhois_version(wsess);
         exit(EXIT_FAILURE);
-    } else if (use_stdin < 1) { 
-        if (strlen(av[optind]) > max_hostname_input) {
-            fprintf(stderr,"Sorry, the host name you supplied was unreasonably long.\n");
+    } else if ((read_from_file > 0 && use_stdin < 1) || go_interactive > 0) { 
+    
+        if (strlen(av[optind]) > max_hostname_input) {        
+            fprintf(stderr,"Sorry, the subject name you supplied was unreasonably long.\n");
             exit(EXIT_FAILURE);
         } else {
+        
             strncpy(hostname,av[optind],strlen(av[optind]));
             optind++;
         }
     }
-            
+    
     if (read_from_file) {
         if (riswhoisfromfile) 
             w_display_bulkfromfile_riswhois(wsess, hostname);
